@@ -1,5 +1,7 @@
 """
-Main interface for rds-data service client
+Type annotations for rds-data service client.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html)
 
 Usage::
 
@@ -48,7 +50,8 @@ class Exceptions:
 
 class RDSDataServiceClient:
     """
-    [RDSDataService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/rds-data.html#RDSDataService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/rds-data.html#RDSDataService.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html)
     """
 
     meta: ClientMeta
@@ -65,26 +68,30 @@ class RDSDataServiceClient:
         transactionId: str = None,
     ) -> BatchExecuteStatementResponseTypeDef:
         """
-        [Client.batch_execute_statement documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#batch-execute-statement)
         """
 
     def begin_transaction(
         self, resourceArn: str, secretArn: str, database: str = None, schema: str = None
     ) -> BeginTransactionResponseTypeDef:
         """
-        [Client.begin_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#begin-transaction)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#can-paginate)
         """
 
     def commit_transaction(
         self, resourceArn: str, secretArn: str, transactionId: str
     ) -> CommitTransactionResponseTypeDef:
         """
-        [Client.commit_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#commit-transaction)
         """
 
     def execute_sql(
@@ -96,7 +103,8 @@ class RDSDataServiceClient:
         schema: str = None,
     ) -> ExecuteSqlResponseTypeDef:
         """
-        [Client.execute_sql documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#execute-sql)
         """
 
     def execute_statement(
@@ -113,7 +121,8 @@ class RDSDataServiceClient:
         transactionId: str = None,
     ) -> ExecuteStatementResponseTypeDef:
         """
-        [Client.execute_statement documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#execute-statement)
         """
 
     def generate_presigned_url(
@@ -124,12 +133,14 @@ class RDSDataServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#generate-presigned-url)
         """
 
     def rollback_transaction(
         self, resourceArn: str, secretArn: str, transactionId: str
     ) -> RollbackTransactionResponseTypeDef:
         """
-        [Client.rollback_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#rollback-transaction)
         """
